/*
 * This file is part of Invenio.
 * Copyright (C) 2015-2018 CERN.
 *
 * Invenio is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

.navbar-static-top {
}

.navbar-brand {
  font-family: $brand-font-family;
  font-size: $brand-font-size;
  line-height: $brand-font-size;
  padding: $navbar-brand-padding-vertical $navbar-padding-horizontal
}

.navbar-gradient {
  background-color: $color1;
}

.navbar-inverse {
  background-color: $color1;
}
